/** 
 *  @file   KBD430_HUT.h
 *  @brief  HID Usage Tags
 */
/* --COPYRIGHT--,BSD
 * Copyright (c) 2014, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * --/COPYRIGHT--*/

#ifndef __KBD430_HUT_h
#define __KBD430_HUT_h


// The following section defines the HID Usage codes for each defined key on the
// keyboard.  These are defined in the HID "Usage Tag" (HUT) specification.

#define hidUsageReserved            0x00
#define hidUsageErrorRollOver       0x01
#define hidUsagePOSTFail            0x02
#define hidUsageErrorUndefined      0x03
#define hidUsageA                   0x04
#define hidUsageB                   0x05
#define hidUsageC                   0x06
#define hidUsageD                   0x07
#define hidUsageE                   0x08
#define hidUsageF                   0x09
#define hidUsageG                   0x0A
#define hidUsageH                   0x0B
#define hidUsageI                   0x0C
#define hidUsageJ                   0x0D
#define hidUsageK                   0x0E
#define hidUsageL                   0x0F
#define hidUsageM                   0x10
#define hidUsageN                   0x11
#define hidUsageO                   0x12
#define hidUsageP                   0x13
#define hidUsageQ                   0x14
#define hidUsageR                   0x15
#define hidUsageS                   0x16
#define hidUsageT                   0x17
#define hidUsageU                   0x18
#define hidUsageV                   0x19
#define hidUsageW                   0x1A
#define hidUsageX                   0x1B
#define hidUsageY                   0x1C
#define hidUsageZ                   0x1D
#define hidUsage1                   0x1E
#define hidUsage2                   0x1F
#define hidUsage3                   0x20
#define hidUsage4                   0x21
#define hidUsage5                   0x22
#define hidUsage6                   0x23
#define hidUsage7                   0x24
#define hidUsage8                   0x25
#define hidUsage9                   0x26
#define hidUsage0                   0x27
#define hidUsageEnter               0x28
#define hidUsageEscape              0x29
#define hidUsageBackspace           0x2A
#define hidUsageTab                 0x2B
#define hidUsageSpacebar            0x2C
#define hidUsageMinus               0x2D
#define hidUsageEqual               0x2E
#define hidUsageLeftBracket         0x2F
#define hidUsageRightBracket        0x30
#define hidUsageBackslash           0x31
#define hidUsageVerticalBar         0x32
#define hidUsageSemicolon           0x33
#define hidUsageApostrophe          0x34
#define hidUsageTilde               0x35
#define hidUsageComma               0x36
#define hidUsagePeriod              0x37
#define hidUsageSlash               0x38
#define hidUsageCapsLock            0x39
#define hidUsageF1                  0x3A
#define hidUsageF2                  0x3B
#define hidUsageF3                  0x3C
#define hidUsageF4                  0x3D
#define hidUsageF5                  0x3E
#define hidUsageF6                  0x3F
#define hidUsageF7                  0x40
#define hidUsageF8                  0x41
#define hidUsageF9                  0x42
#define hidUsageF10                 0x43
#define hidUsageF11                 0x44
#define hidUsageF12                 0x45
#define hidUsagePrintScreen         0x46
#define hidUsageScrollLock          0x47
#define hidUsagePause               0x48
#define hidUsageInsert              0x49
#define hidUsageHome                0x4A
#define hidUsagePageUp              0x4B
#define hidUsageDeleteForward       0x4C
#define hidUsageEnd                 0x4D
#define hidUsagePageDown            0x4E
#define hidUsageRightArrow          0x4F
#define hidUsageLeftArrow           0x50
#define hidUsageDownArrow           0x51
#define hidUsageUpArrow             0x52
#define hidUsageKeypadNumlock       0x53
#define hidUsageKeypadSlash         0x54
#define hidUsageKeypadAsterisk      0x55
#define hidUsageKeypadMinus         0x56
#define hidUsageKeypadPlus          0x57
#define hidUsageKeypadEnter         0x58
#define hidUsageKeypad1             0x59
#define hidUsageKeypad2             0x5A
#define hidUsageKeypad3             0x5B
#define hidUsageKeypad4             0x5C
#define hidUsageKeypad5             0x5D
#define hidUsageKeypad6             0x5E
#define hidUsageKeypad7             0x5F
#define hidUsageKeypad8             0x60
#define hidUsageKeypad9             0x61
#define hidUsageKeypad0             0x62
#define hidUsageKeypadPeriod        0x63
#define hidUsageNonUsBackslash      0x64
#define hidUsageKbdApp              0x65
#define hidUsagePower               0x66
#define hidUsageKeypadEqual         0x67
#define hidUsageF13                 0x68
#define hidUsageF14                 0x69
#define hidUsageF15                 0x6A
#define hidUsageF16                 0x6B
#define hidUsageF17                 0x6C
#define hidUsageF18                 0x6D
#define hidUsageF19                 0x6E
#define hidUsageF20                 0x6F
#define hidUsageF21                 0x70
#define hidUsageF22                 0x71
#define hidUsageF23                 0x72
#define hidUsageF24                 0x73
#define hidUsageExecute             0x74
#define hidUsageHelp                0x75
#define hidUsageMenu                0x76
#define hidUsageSelect              0x77
#define hidUsageStop                0x78
#define hidUsageAgain               0x79
#define hidUsageUndo                0x7A
#define hidUsageCut                 0x7B
#define hidUsageCopy                0x7C
#define hidUsagePaste               0x7D
#define hidUsageFind                0x7E
#define hidUsageMute                0x7F
#define hidUsageVolumeUp            0x80
#define hidUsageVolumneDown         0x81
#define hidUsageLockingCapsLock     0x82
#define hidUsageLockingNumLock      0x83
#define hidUsageLockingScrollLock   0x84
#define hidUsageKeypadComma         0x85
#define hidUsageAS400KeypadEqual    0x86
#define hidUsageInternational1      0x87
#define hidUsageInternational2      0x88
#define hidUsageInternational3      0x89
#define hidUsageInternational4      0x8A
#define hidUsageInternational5      0x8B
#define hidUsageInternational6      0x8C
#define hidUsageInternational7      0x8D
#define hidUsageInternational8      0x8E
#define hidUsageInternational9      0x8F
#define hidUsageLang1               0x90
#define hidUsageLang2               0x91
#define hidUsageLang3               0x92
#define hidUsageLang4               0x93
#define hidUsageLang5               0x94
#define hidUsageLang6               0x95
#define hidUsageLang7               0x96
#define hidUsageLang8               0x97
#define hidUsageLang9               0x98
#define hidUsageAlternateErase      0x99
#define hidUsageSysReq              0x9A
#define hidUsageCancel              0x9B
#define hidUsageClear               0x9C
#define hidUsagePrior               0x9D
#define hidUsageReturn              0x9E
#define hidUsageSeparator           0x9F
#define hidUsageOut                 0xA0
#define hidUsageOper                0xA1
#define hidUsageClearAgain          0xA2
#define hidUsageCrSelProps          0xA3
#define hidUsageExSel               0xA4
#define hidUsageLeftControl         0xE0
#define hidUsageLeftShift           0xE1
#define hidUsageLeftAlt             0xE2
#define hidUsageLeftGUI             0xE3
#define hidUsageRightControl        0xE4
#define hidUsageRightShift          0xE5
#define hidUsageRightAlt            0xE6
#define hidUsageRightGUI            0xE7
#define hidUsageReservedFn          0xF0


#endif //__KBD430_HUT_h
