/** 
 *  @file   KBD430_Keyboard_public.h
 *  @brief  Keyboard header file
 */
/* --COPYRIGHT--,BSD
 * Copyright (c) 2014, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * --/COPYRIGHT--*/
#ifndef __KBD430_Keyboard_public_h
#define __KBD430_Keyboard_public_h

//
// Include files
//
#include "stdint.h"
#include "stdbool.h"
#include "KBD430_DKS.h"     
#include "KBD430_report.h"
#include "KBD430_public_defs.h"


//
// Macros & definitions
//
/*! USBKBD Version (BCD format: 0x0102 = 1.2 */
#define USBKBD_VERSION         (0x0102)

/*! Magic key at the beginning of Table */
#define USBKBD_MAGIC_KEY       (0xDEADC0DE)

/*! Number of keys to store in array, all other keys will be ignored */
#define MAX_KEYS    12  


//
// Type definitions
//
/*! Port+pin definition */
typedef struct {
    volatile uint16_t  pout;        /*!< Port pointer */
    uint8_t         port_mask;      /*!< Port mask */
} USBKBD_Port_t;



/*! key value size */
typedef uint8_t USBKBD_dks_keyval_t;
/*! key value and modifier size */
typedef uint16_t USBKBD_dks_keyvalmod_t;


/*! ScanCode table for USBKBD */
typedef struct {
    USBKBD_dks_keyval_t     keycode[KSO_PINS*KSI_PINS];       /*!< All Keycodes */
} USBKBD_scancodest_t;


#ifndef __IAR_SYSTEMS_ICC__
// This keyword doesn't exist in CCS and is only used with IAR.
#   define __no_init
#endif

//
// Public prototypes
//
extern void KBD430_Keyboard_Init(void);
extern void KBD430_Keyboard_Task(void);
extern bool KBD430_Keyboard_CanSleep(void);


#endif //__KBD430_Keyboard_public_h
