/** 
 *  @file   KBD430_delaytimer_public.h
 *  @brief  Delay Timer header file
 */
/* --COPYRIGHT--,BSD
 * Copyright (c) 2014, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * --/COPYRIGHT--*/
#ifndef __KBD430_delaytimer_public_h
#define __KBD430_delaytimer_public_h


//
// Type definitions
//

/*! Status of DelayTimer */
typedef enum{
    DT_Idle=0,          // Timer is idle
    DT_Inprogress,      // Timer is running 
    DT_Complete,        // Timer delay complete
}DelayTimer_Status_t;

//
// Public function prototypes
//
extern void DelayTimer_DelayMs_Start( uint16_t ms );
extern void DelayTimer_DelayCycles_Start(uint16_t cycles);
extern bool DelayTimer_isComplete(void);
extern void DelayTimer_Clear(void);

//
// Function-like Macros
//
/******************************************************************************
 * @brief   Starts the Tick timer in up mode
 *****************************************************************************/
#define DELAYTIMER_START()    {TA0CTL |= MC__UP;}
/******************************************************************************
 * @brief   Stops the Tick timer
 *****************************************************************************/
#define DELAYTIMER_STOP()     { TA0CTL &= ~MC_3;}


#endif //__KBD430_delaytimer_public_h
