/** 
 *  @file   KBD430_report.h
 *  @brief  HID report builder header file
 */
/* --COPYRIGHT--,BSD
 * Copyright (c) 2014, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * --/COPYRIGHT--*/
#ifndef __KBD430_report_h
#define __KBD430_report_h

#include "KBD430_public_defs.h"

//
// MACROS/DEFINES
//
/*! HID report buffer size (1 modifier, 1 unused, 6 data) */
#define KBDREP_BUFF_SIZE        (8)
/*! MODIFIER offset in report buffer */
#define KBDREP_MOD_OFFSET       (0)
/*! Data offset in report buffer */
#define KBDREP_DATA_OFFSET      (2)
/*! Mark all data slots high */
#define ALL_SLOTS               (0xFC)

/*! Consumer HID report buffer size (1 report ID + 1 Data) */
#define CONSREP_BUFF_SIZE       (2)
/*! Consumer HID report ID */
#define CONSREP_ID              (0x03)
/*! Consumer Report ReportID offset */
#define CONSREP_ID_OFFSET       (0)
/*! Consumer Report Data offset */
#define CONSREP_DATA_OFFSET     (1)

/*! WRC HID report buffer size (1 report ID + 1 Data) */
#define WRCREP_BUFF_SIZE        (2)
/*! WRC HID report ID */
#define WRCREP_ID               (0x04)
/*! Consumer Report ReportID offset */
#define WRCREP_ID_OFFSET        (0)
/*! Consumer Report Data offset */
#define WRCREP_DATA_OFFSET      (1)

//
// Type definition
//
/*! type definition of key value */
typedef  uint8_t key_t;

/*! HID Keyboard buffer */
typedef struct
{
    bool                Update;                     /**< Update report */
    USBKBD_8bitreg_t    EmptySlots;                 /**< emptyslots */
    uint8_t             Size;                       /**< Queue size */
    key_t               Buff[KBDREP_BUFF_SIZE];     /**< Circular buffer elements */
} KBDReportBuffer_t;

/*! Consumer HID Keyboard buffer */
typedef struct
{
    bool                Update;                     /**< Update report */
    uint8_t             Size;                       /**< Queue size */
    key_t               Buff[CONSREP_BUFF_SIZE];    /**< Circular buffer elements */
} ConsReportBuffer_t;

/*! Wireless Control Function HID Keyboard buffer */
typedef struct
{
    bool                Update;                     /**< Update report */
    uint8_t             Size;                       /**< Queue size */
    key_t               Buff[WRCREP_BUFF_SIZE];     /**< Circular buffer elements */
} WRCReportBuffer_t;

//
// Public prototypes
//
extern void KBD430_Report_Init( void );
extern void KBD430_Report_Update(void);
extern bool KBD430_Report_CanSleep(void);
extern bool KBD430_KBDReport_Addkey(key_t keyvalue);
extern bool KBD430_KBDReport_Removekey(key_t keyvalue);

#ifdef USE_CONSUMER_REPORT
extern bool KBD430_ConsReport_Addkey( uint8_t key );
extern bool KBD430_ConsReport_Removekey( uint8_t key );
#endif
#ifdef USE_WRC_REPORT
extern bool KBD430_WRCReport_Addkey( uint8_t key );
extern bool KBD430_WRCReport_Removekey( uint8_t key );
#endif
// declared in Application layer
extern bool KBD430_ReportSend(uint8_t * reportData, uint8_t intfNum);


#endif //__KBD430_report_h
