/** 
 *  @file   KBD430_ScanCodesMap.c
 *  @brief  Map of ScanCodes used by keyboard
 */
/* --COPYRIGHT--,BSD
 * Copyright (c) 2014, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * --/COPYRIGHT--*/
//
// Include files
//
#include "KBD430_HUT.h"
#include "KBD430_Keyboard_public.h"


/*! Scancodes constant table
 *  Can be assigned to a predefined memory location
 *  Can be customized according to different layouts
**/
#ifdef __IAR_SYSTEMS_ICC__
    // Enable pragma to assign to a predefined memory location
    //#pragma location="USBKBD_ScanCodesMap"    
    #pragma data_alignment=512
#endif
#ifdef __TI_COMPILER_VERSION__
    // Enable pragma to assign to a predefined memory location
    //#pragma DATA_SECTION(USBKBD_scancodes_s, ".USBKBD_ScanCodesMap")
    #pragma DATA_ALIGN(USBKBD_scancodes_s, 512)
#endif
const USBKBD_scancodest_t USBKBD_scancodes_s = {
    {hidUsageEscape,            /* 0 , 0 */
    hidUsageTilde,              /* 0 , 1 */
    hidUsageF5,                 /* 0 , 2 */
    hidUsageTab,                /* 0 , 3 */
    hidUsageF1,                 /* 0 , 4 */
    hidUsageF2,                 /* 0 , 5 */
    hidUsageCapsLock,           /* 0 , 6 */
    hidUsageF6,                 /* 0 , 7 */
    hidUsageF11,                /* 1 , 0 */
    hidUsageF12,                /* 1 , 1 */
    hidUsageF8,                 /* 1 , 2 */
    hidUsageQ,                  /* 1 , 3 */
    hidUsageF4,                 /* 1 , 4 */
    hidUsageF3,                 /* 1 , 5 */
    hidUsage1,                  /* 1 , 6 */
    hidUsageF7,                 /* 1 , 7 */
    hidUsageInsert,             /* 2 , 0 */
    hidUsageDeleteForward,      /* 2 , 1 */
    hidUsageReserved,           /* 2 , 2 */
    hidUsagePageUp,             /* 2 , 3 */
    hidUsagePageDown,           /* 2 , 4 */
    hidUsageRightArrow,         /* 2 , 5 */
    hidUsageDownArrow,          /* 2 , 6 */
    hidUsageLeftArrow,          /* 2 , 7 */
    hidUsageF10,                /* 3 , 0 */
    hidUsageF9,                 /* 3 , 1 */
    hidUsageBackspace,          /* 3 , 2 */
    hidUsage3,                  /* 3 , 3 */
    hidUsage2,                  /* 3 , 4 */
    hidUsageUpArrow,            /* 3 , 5 */
    hidUsagePrintScreen,        /* 3 , 6 */
    hidUsagePause,              /* 3 , 7 */
    hidUsageLeftBracket,        /* 4 , 0 */
    hidUsageP,                  /* 4 , 1 */
    hidUsageApostrophe,         /* 4 , 2 */
    hidUsageSemicolon,          /* 4 , 3 */
    hidUsageSlash,              /* 4 , 4 */
    hidUsagePeriod,             /* 4 , 5 */
    hidUsageReserved,           /* 4 , 6 */
    hidUsageReserved,           /* 4 , 7 */
    hidUsageReserved,           /* 5 , 0 */
    hidUsageReserved,           /* 5 , 1 */
    hidUsageReserved,           /* 5 , 2 */
    hidUsageReserved,           /* 5 , 3 */
    hidUsageReserved,           /* 5 , 4 */
    hidUsageRightControl,       /* 5 , 5 */
    hidUsageReserved,           /* 5 , 6 */
    hidUsageLeftControl,        /* 5 , 7 */
    hidUsageReserved,           /* 6 , 0 */
    hidUsageReserved,           /* 6 , 1 */
    hidUsageReserved,           /* 6 , 2 */
    hidUsageReserved,           /* 6 , 3 */
    hidUsageRightShift,         /* 6 , 4 */
    hidUsageLeftShift,          /* 6 , 5 */
    hidUsageReserved,           /* 6 , 6 */
    hidUsageReserved,           /* 6 , 7 */
    hidUsageReserved,           /* 7 , 0 */
    hidUsageEqual,              /* 7 , 1 */
    hidUsageRightBracket,       /* 7 , 2 */
    hidUsageEnter,              /* 7 , 3 */
    hidUsageReserved,           /* 7 , 4 */
    hidUsageReserved,           /* 7 , 5 */
    hidUsageReserved,           /* 7 , 6 */
    hidUsageKbdApp,             /* 7 , 7 */
    hidUsageMinus,              /* 8 , 0 */
    hidUsage0,                  /* 8 , 1 */
    hidUsageO,                  /* 8 , 2 */
    hidUsageI,                  /* 8 , 3 */
    hidUsageL,                  /* 8 , 4 */
    hidUsageK,                  /* 8 , 5 */
    hidUsageComma,              /* 8 , 6 */
    hidUsageM,                  /* 8 , 7 */
    hidUsage9,                  /* 9 , 0 */
    hidUsage8,                  /* 9 , 1 */
    hidUsageU,                  /* 9 , 2 */
    hidUsageY,                  /* 9 , 3 */
    hidUsageJ,                  /* 9 , 4 */
    hidUsageN,                  /* 9 , 5 */
    hidUsageB,                  /* 9 , 6 */
    hidUsageBackslash,          /* 9 , 7 */
    hidUsage7,                  /* 10 , 0 */
    hidUsage6,                  /* 10 , 1 */
    hidUsageT,                  /* 10 , 2 */
    hidUsageH,                  /* 10 , 3 */
    hidUsageG,                  /* 10 , 4 */
    hidUsageV,                  /* 10 , 5 */
    hidUsageC,                  /* 10 , 6 */
    hidUsageSpacebar,           /* 10 , 7 */
    hidUsage5,                  /* 11 , 0 */
    hidUsage4,                  /* 11 , 1 */
    hidUsageR,                  /* 11 , 2 */
    hidUsageE,                  /* 11 , 3 */
    hidUsageF,                  /* 11 , 4 */
    hidUsageD,                  /* 11 , 5 */
    hidUsageX,                  /* 11 , 6 */
    hidUsageReserved,           /* 11 , 7 */
    hidUsageReserved,           /* 12 , 0 */
    hidUsageReserved,           /* 12 , 1 */
    hidUsageReserved,           /* 12 , 2 */
    hidUsageReserved,           /* 12 , 3 */
    hidUsageReserved,           /* 12 , 4 */
    hidUsageReserved,           /* 12 , 5 */
    hidUsageRightAlt,           /* 12 , 6 */
    hidUsageLeftAlt,            /* 12 , 7 */
    hidUsageReserved,           /* 13 , 0 */
    hidUsageReserved,           /* 13 , 1 */
    hidUsageReserved,           /* 13 , 2 */
    hidUsageReserved,           /* 13 , 3 */
    hidUsageReserved,           /* 13 , 4 */
    hidUsageReserved,           /* 13 , 5 */
    hidUsageReserved,           /* 13 , 6 */
    hidUsageLeftGUI,            /* 13 , 7 */
    hidUsageReserved,           /* 14 , 0 */
    hidUsageReserved,           /* 14 , 1 */
    hidUsageW,                  /* 14 , 2 */
    hidUsageS,                  /* 14 , 3 */
    hidUsageA,                  /* 14 , 4 */
    hidUsageZ,                  /* 14 , 5 */
    hidUsageReserved,           /* 14 , 6 */
    hidUsageReservedFn,         /* 14 , 7 */
 }
};

