/* --COPYRIGHT--,BSD
 * Copyright (c) 2014, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * --/COPYRIGHT--*/
/** 
 * @file hidi2cEventHandling.c
 * @brief Event Handler for HID I2C
 * @details This file is included in an application and includes functions which
 * are called by the hid engine
 *
 */

#include "hidi2c_types.h"
#include "hid_engine.h"
#include "hidi2c_settings.h"

extern volatile uint8_t gotoSleep;
extern uint8_t InputReport[]; 
extern volatile BOOL DataReceivedKBD;
extern uint8_t DataReceived;
/**
 * Output report handler.
 *
 * @return TRUE if the user wants to clear LPM bits after this interrupt, FALSE
 * if the user wants the LPM bits not to be touched \
 */
BOOL outputReportEventHandler(uint8_t interface, uint8_t* outputReport)
{
    /* We are only expecting an output report to tell us if LEDs should 
     be on with the keyboard. The LEDs will be handled in main */
    if (outputReport[0] != 1)
    {
      return FALSE;
    }
    else
    {
      DataReceived = outputReport[1];
      DataReceivedKBD = TRUE;
      return TRUE;

    }
     

}

/**
 * Event handler called when a SET_REPORT command is issued by the host. For
 * keyboards/mice, feature reports are not supported so this is a dummy handler
 *
 *
 * @param interface Specific interface being used
 * @param reportid Report ID of the feature report that was set
 * @param feature New feature report
 *
 * @return TRUE if the user wants to clear LPM bits after this interrupt, FALSE
 * if the user wants the LPM bits not to be touched
 */
BOOL handleSetReportCalled(uint8_t interface, uint8_t reportid,
        uint8_t* feature)
{
    return FALSE;
}

/**
 * Event handler that are called when the host receives a command to put the
 * device to sleep or wake it up. It is important to note that these handlers 
 * are called in interrupt context and should be very brief in nature (set a
 * flag
 *
 * @return TRUE if the user wants to clear LPM bits after this interrupt, FALSE
 * if the user wants the LPM bits not to be touched
 */
BOOL goToSleepEventHandler()
{
    gotoSleep = TRUE;
    return TRUE;
}

/**
 * Because LPM bits need to be cleared at the end of the calling interrupt.
 * Returning TRUE from this function will clear the LPM bits on the MSP430 and
 * cause it to wake up from sleep.
 *
 * @return TRUE if the user wants to clear LPM bits after this interrupt, FALSE
 * if the user wants the LPM bits not to be touched
 */
BOOL wakeUpEventHandler()
{
    gotoSleep = FALSE;
    return TRUE;
}

/**
 * Grabs the latest input report from the device.
 *
 * @return uint8_t* Pointer to array with the latest input report.
 */
uint8_t* handleGetReportCalled(uint8_t interface, uint8_t reportid)
{
    return InputReport;
}
