/** 
 *  @file   KBD430_hardware.h
 *  @brief  KBD430 Hardware definition
 */
/* --COPYRIGHT--,BSD
 * Copyright (c) 2014, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * --/COPYRIGHT--*/
#ifndef __KBD430_hardware_h
#define __KBD430_hardware_h

//
//  Header files
//
#include "msp430.h"

//
//  Configuration definitions
//
#define MCLK_FREQ   8000000     /*! MCLK Frequency */
#define ACLK_FREQ   32768       /*! ACLK Frequency */


//
//  Constant HW definitions
//
//  Keyboard inputs:
//    Note: This example only uses one port for all 8 inputs. Any port with 
//          interrupt capability can be used and can be configured below.
//       BITn from the input port is assumed to be KSIn, where n = 0:7.
//       Although the input pins can be assigned to multiple ports, the 
//          the implementation is easier and faster if only one port is used. 
//
/*! Port2 KSI[0:7] */
#define KSI_IN          (P2IN)  /*! KSI Read Port */
#define KSI_OUT         (P2OUT) /*! KSI Write Port */
#define KSI_DIR         (P2DIR) /*! KSI Dir */
#define KSI_IES         (P2IES) /*! Interrupt Edge select */
#define KSI_IFG         (P2IFG) /*! Interrupt Flag */
#define KSI_IE          (P2IE)  /*! Interrupt Enable */
/*! All the pins used as inputs */
#define KSI_ALL         (BIT0|BIT1|BIT2|BIT3|BIT4|BIT5|BIT6|BIT7)
#define KSI_READ()      ((uint8_t) (~(KSI_IN)))
/*! Vector used by the keyboard input port interrupt */
#define KSI_VECTOR      PORT2_VECTOR

//  Keyboard Outputs:
//    Note: Any MCU pin can be used as an output and can be configured below.
//      Each port+pin is mapped in USBKBD_KSO_HAL.
//      The actual address of the port output register is used directly
//          instead of DriverLib in order to save some cycles.
//

#define KSO_PDIR_OFFSET  (2)    /*! F5xxPDIR has an offset of 2 vs POUT*/

/*! Port4 KSO0 */
#define KSO0_POUT       ((uint16_t) &P4OUT)     /*! KSO0 Port */
#define KSO0_BIT        BIT7                    /*! KSO0 Pin */
/*! All KSO pins assigned to P4 */
#define KSO_P4_ALL      (BIT7)

/*! Port5 KSO[1:4] */
#define KSO1_POUT       ((uint16_t) &P5OUT)     /*! KSO1 Port */
#define KSO1_BIT        BIT4                    /*! KSO1 Pin */
#define KSO2_POUT       ((uint16_t) &P5OUT)     /*! KSO2 Port */
#define KSO2_BIT        BIT5                    /*! KSO2 Pin */
#define KSO3_POUT       ((uint16_t) &P5OUT)     /*! KSO3 Port */
#define KSO3_BIT        BIT6                    /*! KSO3 Pin */
#define KSO4_POUT       ((uint16_t) &P5OUT)     /*! KSO4 Port */
#define KSO4_BIT        BIT7                    /*! KSO4 Pin */
/*! All KSO pins assigned to P5 */
#define KSO_P5_ALL      (BIT4|BIT5|BIT6|BIT7)

/*! Port6 KSO[5:6] */
#define KSO5_POUT       ((uint16_t) &P6OUT)     /*! KSO5 Port */
#define KSO5_BIT        BIT6                    /*! KSO5 Pin */
#define KSO6_POUT       ((uint16_t) &P6OUT)     /*! KSO6 Port */
#define KSO6_BIT        BIT7                    /*! KSO6 Pin */
/*! All KSO pins assigned to P6 */
#define KSO_P6_ALL      (BIT6|BIT7)

/*! Port7 KSO[7:11] */
#define KSO7_POUT       ((uint16_t) &P7OUT)     /*! KSO7 Port */
#define KSO7_BIT        BIT0                    /*! KSO7 Pin */
#define KSO8_POUT       ((uint16_t) &P7OUT)     /*! KSO8 Port */
#define KSO8_BIT        BIT1                    /*! KSO8 Pin */
#define KSO9_POUT       ((uint16_t) &P7OUT)     /*! KSO9 Port */
#define KSO9_BIT        BIT2                    /*! KSO9 Pin */
#define KSO10_POUT      ((uint16_t) &P7OUT)     /*! KSO10 Port */
#define KSO10_BIT       BIT3                    /*! KSO10 Pin */
#define KSO11_POUT      ((uint16_t) &P7OUT)     /*! KSO11 Port */
#define KSO11_BIT       BIT7                    /*! KSO11 Pin */
/*! All KSO pins assigned to P7 */
#define KSO_P7_ALL      (BIT0|BIT1|BIT2|BIT3|BIT7)

/*! Port8 KSO[12:14] */
#define KSO12_POUT      ((uint16_t) &P8OUT)     /*! KSO12 Port */
#define KSO12_BIT       BIT0                    /*! KSO12 Pin */
#define KSO13_POUT      ((uint16_t) &P8OUT)     /*! KSO13 Port */
#define KSO13_BIT       BIT1                    /*! KSO13 Pin */
#define KSO14_POUT      ((uint16_t) &P8OUT)     /*! KSO14 Port */
#define KSO14_BIT       BIT2                    /*! KSO14 Pin */
/*! All KSO pins assigned to P5 */
#define KSO_P8_ALL      (BIT0|BIT1|BIT2)

//
// Keyboard macros
//  Note: These macros are used to set all pins at once faster.
//      They must be modified when using a different HAL.
//
/*! Set all KSO pins as output low to detect interrupt on KSI pins */
#define SET_KSO_INTERRUPT() {P4OUT &= ~KSO_P4_ALL; P4DIR |= KSO_P4_ALL;\
                             PCOUT &= ~(KSO_P5_ALL|(KSO_P6_ALL<<8)); PCDIR |= (KSO_P5_ALL|(KSO_P6_ALL<<8));\
                             PDOUT &= ~(KSO_P7_ALL|(KSO_P8_ALL<<8)); PDDIR |= (KSO_P7_ALL|(KSO_P8_ALL<<8));}
/*! Set KSO pins as input without pull-resistor to poll each row */
#define SET_KSO_POLL()      {P4REN &= ~KSO_P4_ALL; P4DIR &= ~KSO_P4_ALL;\
                             PCREN &= ~(KSO_P5_ALL|(KSO_P6_ALL<<8)); PCDIR &= ~(KSO_P5_ALL|(KSO_P6_ALL<<8));\
                             PDREN &= ~(KSO_P7_ALL|(KSO_P8_ALL<<8)); PDDIR &= ~(KSO_P7_ALL|(KSO_P8_ALL<<8));}
/*! Set KSO pins as input with pull-resistor to avoid extra current */
#define SET_KSO_IDLE()      {P4OUT |= KSO_P4_ALL; P4REN |= KSO_P4_ALL;\
                             PCOUT |= (KSO_P5_ALL|(KSO_P6_ALL<<8)); PCREN |= (KSO_P5_ALL|(KSO_P6_ALL<<8));\
                             PDOUT |= (KSO_P7_ALL|(KSO_P8_ALL<<8)); PDREN |= (KSO_P7_ALL|(KSO_P8_ALL<<8)); }


//
// Definition of LEDs
#define LED_PORT_W      P1OUT           /*! LED Output Port */
#define LEDNUM_1_1      BIT1            /*! NUM LOCK LED pin */
#define LEDCAPS_1_6     BIT6            /*! CAPS LOCK LED pin */
#define LEDSCROLL_1_7   BIT7            /*! SCROLL LOCK LED pin */


#endif //__KBD430_hardware_h
