/** 
 *  @file   KBD430_report_App.c
 *  @brief  Sends the report to the corresponding interface
 */
/* --COPYRIGHT--,BSD
 * Copyright (c) 2014, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * --/COPYRIGHT--*/
//
// Include files
//
#include "KBD430_Keyboard_public.h"
#include "hidi2c_types.h"
#include "hid_engine.h"
#include "hidi2c_settings.h"

//
// Public functions
//
/******************************************************************************
 * @brief  Sends a report to the corresponding interface
 *  This function is called by KBD430 but should be defined in application 
 *  layer to send to the appropiate interface
 *
 * @param  reportData  Pointer to the report buffer
 * @param  intNum       Number of the interface
 *
 * @return  true if OK, false if error
 *****************************************************************************/
bool KBD430_ReportSend(uint8_t * reportData, uint8_t intfNum)
{
  
    /* Sending the report to this host */
    switch (intfNum)
    {
        case HID_Keyboard:
            // Standard keyboard interface, send with ReportID 1
            // Keyboard data is not sent with ReportID by KBD driver
            setInputReportAndInitiateSend(USCIB1, reportData, 1);
        break;
        case HID_Consumer:
            // Consumer Control, Send with ReportID 3
            // Keyboard data includes reportID in first byte
            setInputReportAndInitiateSend(USCIB1, &reportData[1], reportData[0]);
        break;
        case HID_WRC:
            // Wireless Control, Send with ReportID 4
            // Keyboard data includes reportID in first byte
            setInputReportAndInitiateSend(USCIB1, &reportData[1], reportData[0]);
        break;
    }
    
    return true;
}
