/* --COPYRIGHT--,BSD
 * Copyright (c) 2014, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * --/COPYRIGHT--*/
/**
 * @file keyboard_descriptors.h
 * @brief HID report descriptor and other variables for keyboard example
 */

/*----------------------------------------------------------------------------+
 |                                                                             |
 |                              Texas Instruments                              |
 |                                                                             |
 |                          HID Keyboard Example Include                       |
 |                                                                             |
 +----------------------------------------------------------------------------*/
#include "hidi2c_types.h"
#include <stdint.h>

/* Report Descriptor for Keyboard */
const uint8_t report_desc_HID0[] =
{ 
    0x05, 0x01, 	    // Usage Page (Generic Desktop)
    0x09, 0x06,		    // Usage (Keyboard)
    0xA1, 0x01,		    // Collection (Application)
    0x85, 0x01,         // Report_ID (1)
    0x05, 0x07,		    // Usage Page (Key Codes)
    0x19, 0xE0,		    // Usage Minimum (224)
    0x29, 0xE7,		    // Usage Maximum (231)
    0x15, 0x00,		    // Logical Minimum (0)
    0x25, 0x01,		    // Logical Maximum (1)
    0x75, 0x01,		    // Report Size (1)
    0x95, 0x08,		    // Report Count (8)
    0x81, 0x02,		    // Input (Data, Variable, Absolute) -- Modifier byte
    0x95, 0x01,		    // Report Count (1)
    0x75, 0x08,	 	    // Report Size (8)
    0x81, 0x03,             // (81 01) Input (Constant) -- Reserved byte
    0x95, 0x05,             // Report Count (5)
    0x75, 0x01,             // Report Size (1)
    0x05, 0x08,             // Usage Page (Page# for LEDs)
    0x19, 0x01,             // Usage Minimum (1)
    0x29, 0x05,	            // Usage Maximum (5)
    0x91, 0x02,	            // Output (Data, Variable, Absolute) -- LED report
    0x95, 0x01,	            // Report Count (1)
    0x75, 0x03,	            // Report Size (3)
    0x91, 0x03,	            // (91 03) Output (Constant) -- LED report padding
    0x95, 0x06,             // Report Count (6)
    0x75, 0x08,             // Report Size (8)
    0x15, 0x00,	            // Logical Minimum (0)
    0x25, 0x66,             // Logical Maximum(102)  // was 0x65
    0x05, 0x07,             // Usage Page (Key Codes)
    0x19, 0x00,             // Usage Minimum (0)
    0x29, 0x66,	            // Usage Maximum (102) // was 0x65
    0x81, 0x00,	            // Input (Data, Array) -- Key arrays (6 bytes)
    0xC0,                   // End Collection

    /* Report Descriptor for Consumer Control report (multimedia keys) */
    0x05, 0x0C,       // Usage Page (Consumer)
    0x09, 0x01,         // Usage (Consumer Control)
    0xA1, 0x01,              // Collection (Application)
    0x85, 0x03,               // Report Id
    0x09, 0xE9,               // Usage (Volume Increment)
    0x15, 0x00,               // Logical Minimum (0)
    0x25, 0x01,               // Logical Maximum (1)
    0x75, 0x01,               // Report Size (1)
    0x95, 0x01,               // Report Count (1)
    0x81, 0x06,               // Input(Data, Value, Relative,BitField) Bit0
    0x09, 0xEA,               // Usage (Volume Decrement)
    0x81, 0x06,               // Input(Data, Value, Relative,BitField) Bit1
    0x09, 0xE2,               // Usage (Mute)
    0x81, 0x06,               // Input(Data, Value, Relative,BitField) Bit2
    0x09, 0xB5,               // Usage (Scan Next Track)
    0x81, 0x06,               // Input(Data, Value, Relative,BitField) Bit3
    0x09, 0xB6,               // Usage (Scan Previous Track)
    0x81, 0x06,               // Input(Data, Value, Relative,BitField) Bit4
    0x09, 0xCD,               // Usage (Play/Pause)
    0x81, 0x06,               // Input(Data, Value, Relative,BitField) Bit5
    0x09, 0x6F,               // Usage (Brightness Increase)
    0x81, 0x06,               // Input(Data, Value, Relative,BitField) Bit6
    0x09, 0x70,               // Usage (Brightness Decrease)
    0x81, 0x06,               // Input(Data, Value, Relative,BitField) Bit7
    0xC0,                   // End Collection
    
    /* Report Descriptor for Wireless Radio Control */
    0x05, 0x01,       // Usage Page (Generic Desktop)
    0x09, 0x0C,          // USAGE (Wireless Radio Controls)
    0xA1, 0x01,             // Collection (Application)
    0x85, 0x04,       // Report Id
    0x15, 0x00,               // Logical Minimum (0)
    0x25, 0x01,               // Logical Maximum (1)
    0x09, 0xC6,               // Usage (Wireless Radio Button)
    0x95, 0x01,               // Report Count (1)
    0x75, 0x01,               // Report Size (1)
    0x81, 0x06,               // Input(Data, Value, Relative,BitField)
    0x75, 0x07,               // Report Size (7)
    0x81, 0x03,               // Input(Const, Value, Relative,BitField)
    0xC0,                   // End Collection								// end Application Collection

      
};


/* Size of input report (including size field) */
#define INPUT_REPORT_SIZE              9
